@@ -11,8 +11,11 @@ module Data.Cache.LRU
     , newLRU
     , fromList
     , toList
+    , pairs
+    , keys
     , maxSize
     , insert
+    , insertInforming
     , lookup
     , delete
     , pop
