@@ -143,7 +143,7 @@ insertInforming key val lru = maybe emptyCase nonEmptyCase $ first lru
 
       -- create a new LRU with a new first item, and
       -- conditionally dropping the last item
-      add firstKey = if full then (lru'', Just (key, val))
+      add firstKey = if full then (lru'', Just (lastKey, value lastLV))
                      else (lru', Nothing)
           where
             -- add a new first item
